/*
 * Copyright (C) 2006-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.codehaus.mojo.groovy.gossip.model;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * ???
 *
 * @version $Id: Activation.java 5485 2007-10-24 23:55:48Z user57 $
 * @author <a href="mailto:jason@planet57.com">Jason Dillon</a>
 */
public class Activation
    extends ContainerNode
{
    private List triggers;

    public List triggers() {
        if (triggers == null) {
            triggers = new ArrayList();
        }

        return triggers;
    }

    public void addTrigger(final Trigger node) {
        assert node != null;

        triggers().add(node);
        node.setParent(this);
    }

    public boolean isActive() {
        // No triggers means its not active
        if (triggers == null) {
            log.debug("No triggers found; profile is not active");
            
            return false;
        }

        log.debug("Checking for active triggers:");

        for (Iterator iter = triggers().iterator(); iter.hasNext();) {
            Trigger trigger = (Trigger) iter.next();

            // If not active, then stop now
            if (!trigger.isActive()) {
                log.debug("    {}", trigger);

                return false;
            }
            else {
                log.debug("    {} (ACTIVE)", trigger);
            }
        }
        
        // Else all triggers are active so we are active
        return true;
    }
}